@@ -3,8 +3,8 @@ from dstf import *
 
 def test_apply__append():
     task = Task("t0")
-    node = Node("n0")
-    sched = Schedule().update(AppendOperator(task, 0, {node: 10}))
+    node = "n0"
+    sched = Schedule().apply(AppendOperator(task, 0, {node: 10}))
 
     assert task in sched
     assert len(sched[task]) == 1
@@ -14,8 +14,8 @@ def test_apply__append():
 
 def test_apply__preempt():
     task = Task("t0")
-    node = Node("n0")
-    sched = Schedule().update(AppendOperator(task, 0, {node: 10})).update(PreemptOperator(task, 5, {node: 10}))
+    node = "n0"
+    sched = Schedule().apply(AppendOperator(task, 0, {node: 10})).apply(PreemptOperator(task, 5, {node: 10}))
 
     assert task in sched
     assert len(sched[task]) == 2
